==> haskell-doctemplates-0.8.2-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctemplates
version:              0.8.2
visibility:           public
id:                   doctemplates-0.8.2-JUAkrGnA4GhDvX4zUfUktU
key:                  doctemplates-0.8.2-JUAkrGnA4GhDvX4zUfUktU
license:              BSD-3-Clause
copyright:            2016-19 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/doctemplates#readme
synopsis:             Pandoc-style document templates
description:
    This is the text templating system used by pandoc.
    It supports variable interpolation, iteration,
    tests for non-blank values, pipes, and partials.
    Templates are rendered to doclayout Docs,
    and variable values may come from a variety of
    different sources, including aeson Values.

category:             Text
abi:                  785bd008ab2b4c0ad5d115d653d21b4f
exposed:              True
exposed-modules:
    Text.DocTemplates Text.DocTemplates.Internal
    Text.DocTemplates.Parser

import-dirs:          /usr/lib/ghc-8.10.2/site-local/doctemplates-0.8.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/doctemplates-0.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctemplates
hs-libraries:         HSdoctemplates-0.8.2-JUAkrGnA4GhDvX4zUfUktU
depends:
    HsYAML-0.2.1.0-5O65RZlb6yq6hwwlDjjqf5
    aeson-1.5.3.0-788DMSG0NArJAGIuz9d2Ai base-4.14.1.0
    containers-0.6.2.1 doclayout-0.3-68CSgr5iMxq4LLe9mAzUxO
    filepath-1.4.2.1 mtl-2.2.2 parsec-3.1.14.0
    safe-0.3.19-AfrHSVViU1189qUhjBUb5b
    scientific-0.3.6.2-7xwfjLGR8Bo21WSiT6C1fZ text-1.2.3.2
    text-conversions-0.3.0-6lGRqOfBK38A5KlQr7qIcU
    unordered-containers-0.2.12.0-32hypcNpCYxF7nyZEjDl6X
    vector-0.12.1.2-1NVIFdUJ04d5LWJjqOrbRq

haddock-interfaces:
    /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock

haddock-html:         /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctemplates-0.8.2-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctemplates.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctemplates
version:              0.8.2
visibility:           public
id:                   doctemplates-0.8.2-EMBAloKKdUuE5zJJBVfy4I
key:                  doctemplates-0.8.2-EMBAloKKdUuE5zJJBVfy4I
license:              BSD-3-Clause
copyright:            2016-19 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/doctemplates#readme
synopsis:             Pandoc-style document templates
description:
    This is the text templating system used by pandoc.
    It supports variable interpolation, iteration,
    tests for non-blank values, pipes, and partials.
    Templates are rendered to doclayout Docs,
    and variable values may come from a variety of
    different sources, including aeson Values.

category:             Text
abi:                  89e018140400e3ac42f57772af9f43b5
exposed:              True
exposed-modules:
    Text.DocTemplates Text.DocTemplates.Internal
    Text.DocTemplates.Parser

import-dirs:          /usr/lib/ghc-8.10.2/site-local/doctemplates-0.8.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/doctemplates-0.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctemplates
hs-libraries:         HSdoctemplates-0.8.2-EMBAloKKdUuE5zJJBVfy4I
depends:
    HsYAML-0.2.1.0-5O65RZlb6yq6hwwlDjjqf5
    aeson-1.5.3.0-HJgqP6RhegPJh4mTnTi74F base-4.14.1.0
    containers-0.6.2.1 doclayout-0.3-68CSgr5iMxq4LLe9mAzUxO
    filepath-1.4.2.1 mtl-2.2.2 parsec-3.1.14.0
    safe-0.3.19-AfrHSVViU1189qUhjBUb5b
    scientific-0.3.6.2-7xwfjLGR8Bo21WSiT6C1fZ text-1.2.3.2
    text-conversions-0.3.0-6lGRqOfBK38A5KlQr7qIcU
    unordered-containers-0.2.12.0-32hypcNpCYxF7nyZEjDl6X
    vector-0.12.1.2-1NVIFdUJ04d5LWJjqOrbRq

haddock-interfaces:
    /usr/share/doc/haskell-doctemplates/html/doctemplates.haddock

haddock-html:         /usr/share/doc/haskell-doctemplates/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
